# Модуль с инструментами для машинного обучения

## Реализованные инструменты

* [Логистическая регрессия](https://github.com/Ackrome/matplobblib/tree/master/matplobblib/ml/logreg#readme)
* [Модели регрессии](https://github.com/Ackrome/matplobblib/tree/master/matplobblib/ml/rm#readme)
* [Дерево](https://github.com/Ackrome/matplobblib/tree/master/matplobblib/ml/tree#readme)
* [SVC](https://github.com/Ackrome/matplobblib/tree/master/matplobblib/ml/svc#readme)
* [K-nn](https://github.com/Ackrome/matplobblib/tree/master/matplobblib/ml/knn#readme)
* [Дополнительные функции](https://github.com/Ackrome/matplobblib/tree/master/matplobblib/ml/additional_funcs#readme)
